@@ -8,6 +8,8 @@ from django.db import models
 from django.utils import timezone
 from django_extensions.db.models import TimeStampedModel
 from music.models import Track
+from podcasts.models import Episode
+from scrobbles.utils import check_scrobble_for_finish
 from videos.models import Video
 
 logger = logging.getLogger(__name__)
@@ -22,6 +24,9 @@ TRACK_WAIT_PERIOD = getattr(settings, 'MUSIC_WAIT_PERIOD_MINUTES')
 class Scrobble(TimeStampedModel):
     video = models.ForeignKey(Video, on_delete=models.DO_NOTHING, **BNULL)
     track = models.ForeignKey(Track, on_delete=models.DO_NOTHING, **BNULL)
+    podcast_episode = models.ForeignKey(
+        Episode, on_delete=models.DO_NOTHING, **BNULL
+    )
     user = models.ForeignKey(
         User, blank=True, null=True, on_delete=models.DO_NOTHING
     )
@@ -37,28 +42,25 @@ class Scrobble(TimeStampedModel):
 
     @property
     def percent_played(self) -> int:
-        if self.playback_position_ticks and self.media_run_time_ticks:
+        if (
+            self.playback_position_ticks
+            and self.media_obj.run_time_ticks
+            and source != 'Mopidy'
+        ):
             return int(
-                (self.playback_position_ticks / self.media_run_time_ticks)
+                (self.playback_position_ticks / self.media_obj.run_time_ticks)
                 * 100
             )
-        # If we don't have media_run_time_ticks, let's guess from created time
+        # If we don't have media_obj.run_time_ticks, let's guess from created time
         now = timezone.now()
         playback_duration = (now - self.created).seconds
-        if playback_duration and self.track.run_time:
-            return int((playback_duration / int(self.track.run_time)) * 100)
+        if playback_duration and self.media_obj.run_time:
+            return int(
+                (playback_duration / int(self.media_obj.run_time)) * 100
+            )
 
         return 0
 
-    @property
-    def media_run_time_ticks(self) -> int:
-        if self.video:
-            return self.video.run_time_ticks
-        if self.track:
-            return self.track.run_time_ticks
-        # this is hacky, but want to avoid divide by zero
-        return 1
-
     def is_stale(self, backoff, wait_period) -> bool:
         scrobble_is_stale = self.in_progress and self.modified > wait_period
 
@@ -79,16 +81,19 @@ class Scrobble(TimeStampedModel):
 
         return scrobble_is_stale
 
-    def __str__(self):
-        media = None
+    @property
+    def media_obj(self):
+        media_obj = None
         if self.video:
-            media = self.video
+            media_obj = self.video
         if self.track:
-            media = self.track
+            media_obj = self.track
+        if self.podcast_episode:
+            media_obj = self.podcast_episode
+        return media_obj
 
-        return (
-            f"Scrobble of {media} {self.timestamp.year}-{self.timestamp.month}"
-        )
+    def __str__(self):
+        return f"Scrobble of {self.media_obj} {self.timestamp.year}-{self.timestamp.month}"
 
     @classmethod
     def create_or_update_for_video(
@@ -134,6 +139,28 @@ class Scrobble(TimeStampedModel):
             scrobble, backoff, wait_period, scrobble_data
         )
 
+    @classmethod
+    def create_or_update_for_podcast_episode(
+        cls, episode: "Episode", user_id: int, scrobble_data: dict
+    ) -> "Scrobble":
+        scrobble_data['podcast_episode_id'] = episode.id
+        scrobble = (
+            cls.objects.filter(podcast_episode=episode, user_id=user_id)
+            .order_by('-modified')
+            .first()
+        )
+        logger.debug(
+            f"Found existing scrobble for podcast {episode}, updating",
+            {"scrobble_data": scrobble_data},
+        )
+
+        backoff = timezone.now() + timedelta(seconds=TRACK_BACKOFF)
+        wait_period = timezone.now() + timedelta(minutes=TRACK_WAIT_PERIOD)
+
+        return cls.update_or_create(
+            scrobble, backoff, wait_period, scrobble_data
+        )
+
     @classmethod
     def update_or_create(
         cls,
@@ -147,6 +174,13 @@ class Scrobble(TimeStampedModel):
         mopidy_status = scrobble_data.pop('status', None)
         scrobble_is_stale = False
 
+        if scrobble:
+            logger.debug(f"Updating scrobble ticks")
+            scrobble.playback_position_ticks = scrobble_data.get(
+                "playback_position_ticks"
+            )
+            scrobble.save(update_fields=['playback_position_ticks'])
+
         if mopidy_status == "stopped":
             logger.info(f"Mopidy sent a message to stop {scrobble}")
             if not scrobble:
@@ -157,7 +191,37 @@ class Scrobble(TimeStampedModel):
 
             # Mopidy finished a play, scrobble away
             scrobble.in_progress = False
-            scrobble.save(update_fields=['in_progress'])
+            scrobble.played_to_completion = True
+            scrobble.save(
+                update_fields=['in_progress', 'played_to_completion']
+            )
+            return scrobble
+
+        if mopidy_status == "paused":
+            logger.info(f"Mopidy sent a message to pause {scrobble}")
+            if not scrobble:
+                logger.info("Message to pause while not started, ignoring")
+                return
+            if scrobble.is_paused:
+                logger.info("Message to pause while paused, ignoring")
+                return
+
+            # Mopidy finished a play, scrobble away
+            scrobble.is_paused = True
+            scrobble.save(update_fields=["is_paused"])
+            scrobble = check_scrobble_for_finish(scrobble)
+            return scrobble
+
+        if mopidy_status == "resumed":
+            logger.info(f"Mopidy sent a message to resume {scrobble}")
+            if not scrobble:
+                logger.info("Message to resume while not started, ignoring")
+                return
+            if not scrobble.is_paused:
+                logger.info("Message to resume while not paused, resuming")
+            # Mopidy finished a play, scrobble away
+            scrobble.is_paused = False
+            scrobble.save(update_fields=["is_paused"])
             return scrobble
 
         if scrobble and not mopidy_status:
@@ -185,16 +249,6 @@ class Scrobble(TimeStampedModel):
 
         # If we hit our completion threshold, save it and get ready
         # to scrobble again if we re-watch this.
-        if scrobble.percent_played >= getattr(
-            settings, "PERCENT_FOR_COMPLETION", 95
-        ):
-            scrobble.in_progress = False
-            scrobble.playback_position_ticks = scrobble.media_run_time_ticks
-            scrobble.save()
-
-        if scrobble.percent_played % 5 == 0:
-            if getattr(settings, "KEEP_DETAILED_SCROBBLE_LOGS", False):
-                scrobble.scrobble_log += f"\n{str(scrobble.timestamp)} - {scrobble.playback_position} - {str(scrobble.playback_position_ticks)} - {str(scrobble.percent_played)}%"
-                scrobble.save(update_fields=['scrobble_log'])
+        scrobble = check_scrobble_for_finish(scrobble)
 
         return scrobble
